Stan Math Library: stan/math/prim/scal/fun/grad_inc_beta.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
grad_inc_beta.hpp File Reference
`#include <stan/math/prim/scal/fun/lbeta.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <stan/math/prim/scal/fun/inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/grad_2F1.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::grad_inc_beta (double &g1, double &g2, double a, double b, double z)

[ Stan Home Page ] © 2011–2016, Stan Development Team.